/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.sge;

import java.io.File;
import java.io.IOException;

import org.glite.apel.core.log.type.EventRecord;

import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Tests to validate the functionality of the EvemtLogParser class.
 */
public class EventLogParserTest extends TestCase {
	/*
	 * Only part of the Condor record is built
         * NB: WCT and CPU quantities appear twice in the actual job record!
	 */

    private String jobRecord="nodoCesga099:compute-1-0.local:cesga:cesga099:" +
                             "STDIN:505575:sge:0:1138725713:1138725881:1138726018:" +
                             "0:0:137:2:1:0.000000:0:0:0:0:126531:0:0:0.000000:0:0:0:0:6392:" +
                             "1080:NONE:defaultdepartment:NONE:1:0:3.000000:0.002480:0.000000:" +
                             "-U cesga099 -q nodoCesga099 -l h_fsize=5G,num_proc=1,s_rt=36000,s_vmem=512M:" +
                             "0.000000:NONE:60420096.000000";

   // Quantities derived from this record
    private String cpuDurationSeconds="3";
    private String cpuDuration="P3S";
    private String jobName="505575";
    private String user="cesga099";
    private String group="cesga"; 
    private String wallDurationSeconds="137";
    private String startTimeEpoch="1138725881";
    private String stopTimeEpoch="1138726018";
    private String EventDate="2006-01-31";
    private String EventTime="16:46:58";

	
    public static junit.framework.Test suite() {
        return new TestSuite(EventLogParserTest.class);
    }

    /**
     * Constructs a dummy event record, returning it as a string.
     */
    private String constructEvent() {
        return jobRecord;
    }

    /**
     * Checks the event parser successfully interprets an event log entry.
     */
    public void testParse() {
        String input = constructEvent();
        File tmp = null;
        try {
        	tmp = File.createTempFile("unittest", "tmp");
            tmp.deleteOnExit();
        } catch (IOException ioe) {
        	fail();
        }
        EventLogParser parser = new EventLogParser(tmp, "","");
        EventRecord record = parser.createEventRecord(input);
        assertEquals(record.getCpuDuration(), cpuDuration);
        assertEquals(record.getCpuDurationSeconds(),cpuDurationSeconds);
        assertEquals(record.getJobName(), jobName);
        assertEquals(record.getLocalUserGroup(), group);
        assertEquals(record.getLocalUserID(), user);
        assertEquals(record.getEventDate(), EventDate);
        assertEquals(record.getEventTime(), EventTime);
        //assertEquals(record.getMemoryReal(), memReal);
        //assertEquals(record.getMemoryVirtual(), memVirtual);
        assertEquals(record.getStartTimeEpoch(), startTimeEpoch);
        assertEquals(record.getStopTimeEpoch(), stopTimeEpoch);
        assertEquals(record.getWallDurationSeconds(), wallDurationSeconds);
        //assertEquals(record.getWallDuration(), WCT);
        //assertEquals(record.getSubmitHost(), submitHost);
    }

}
